@@ -1,3 +1,19 @@
+function _aws_cdk_aws_managedblockchain_CfnAccessorProps(p) {
+    if (p == null)
+        return;
+    visitedObjects.add(p);
+    try {
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
+    }
+    finally {
+        visitedObjects.delete(p);
+    }
+}
+function _aws_cdk_aws_managedblockchain_CfnAccessor(p) {
+}
 function _aws_cdk_aws_managedblockchain_CfnMemberProps(p) {
     if (p == null)
         return;
@@ -70,4 +86,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_managedblockchain_CfnMemberProps, _aws_cdk_aws_managedblockchain_CfnMember, _aws_cdk_aws_managedblockchain_CfnMember_ApprovalThresholdPolicyProperty, _aws_cdk_aws_managedblockchain_CfnMember_MemberConfigurationProperty, _aws_cdk_aws_managedblockchain_CfnMember_MemberFabricConfigurationProperty, _aws_cdk_aws_managedblockchain_CfnMember_MemberFrameworkConfigurationProperty, _aws_cdk_aws_managedblockchain_CfnMember_NetworkConfigurationProperty, _aws_cdk_aws_managedblockchain_CfnMember_NetworkFabricConfigurationProperty, _aws_cdk_aws_managedblockchain_CfnMember_NetworkFrameworkConfigurationProperty, _aws_cdk_aws_managedblockchain_CfnMember_VotingPolicyProperty, _aws_cdk_aws_managedblockchain_CfnNodeProps, _aws_cdk_aws_managedblockchain_CfnNode, _aws_cdk_aws_managedblockchain_CfnNode_NodeConfigurationProperty };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_managedblockchain_CfnAccessorProps, _aws_cdk_aws_managedblockchain_CfnAccessor, _aws_cdk_aws_managedblockchain_CfnMemberProps, _aws_cdk_aws_managedblockchain_CfnMember, _aws_cdk_aws_managedblockchain_CfnMember_ApprovalThresholdPolicyProperty, _aws_cdk_aws_managedblockchain_CfnMember_MemberConfigurationProperty, _aws_cdk_aws_managedblockchain_CfnMember_MemberFabricConfigurationProperty, _aws_cdk_aws_managedblockchain_CfnMember_MemberFrameworkConfigurationProperty, _aws_cdk_aws_managedblockchain_CfnMember_NetworkConfigurationProperty, _aws_cdk_aws_managedblockchain_CfnMember_NetworkFabricConfigurationProperty, _aws_cdk_aws_managedblockchain_CfnMember_NetworkFrameworkConfigurationProperty, _aws_cdk_aws_managedblockchain_CfnMember_VotingPolicyProperty, _aws_cdk_aws_managedblockchain_CfnNodeProps, _aws_cdk_aws_managedblockchain_CfnNode, _aws_cdk_aws_managedblockchain_CfnNode_NodeConfigurationProperty };
